import time
import os.path
import itertools
from random import randint, choice
from asciimatics.screen import Screen

AVAILABLE_COLORS = [
    'COLOUR_RED',
    'COLOUR_GREEN',
    'COLOUR_YELLOW',
    'COLOUR_BLUE',
    'COLOUR_MAGENTA',
    'COLOUR_CYAN',
    'COLOUR_WHITE',
]


def read_frames(location='./frames'):
    frames = []
    path = os.path.abspath(os.path.join(os.path.dirname(__file__), location))
    if not os.path.exists(path):
        raise ValueError("Frames path doesn't exist")
    for i in itertools.count():
        fname = os.path.join(path, '{}.txt'.format(i))
        if os.path.exists(fname):
            with open(fname, 'r') as fp:
                frames.append(fp.read().rstrip())
        else:
            return frames


def main(screen):
    frames = read_frames()
    for frame in itertools.cycle(frames):
        color_attr = choice(AVAILABLE_COLORS)
        color = getattr(Screen, color_attr)
        for i, line in enumerate(frame.split('\n')):
            screen.paint(
                line, 0, i,
                colour=color)
        ev = screen.get_key()
        if ev in (ord('Q'), ord('q')):
            return
        screen.refresh()
        screen.clear()


def party():
    Screen.wrapper(main)

if __name__ == '__main__':
    party()



import setuptools


setuptools.setup(
    name="party-parrot",
    version="0.0.2",
    author="Santiago Basulto",
    author_email="santiago.basulto@gmail.com",
    description="Party or die",
    long_description="A funny package to join Parrot's party",
    long_description_content_type="text/markdown",
    url="https://github.com/santiagobasulto/party-parrot",
    packages=['party_parrot'],
    package_data={
        'party_parrot': ['frames/*.txt'],
    },
    scripts=['main.py'],
    entry_points={
        'console_scripts': [
            'party = main:party'
        ]
    },
    install_requires=[
        "asciimatics==1.9.0",
    ],
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)
